import { useState, useCallback, memo, useMemo } from 'react';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Textarea } from '@/components/ui/textarea';
import { Checkbox } from '@/components/ui/checkbox';
import { Card, CardContent } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Play, Menu, X, Zap, Cpu, Brain, Sparkles, Phone, Mail, CheckCircle, Clock, Shield, TrendingUp } from 'lucide-react';
import { motion, AnimatePresence } from 'framer-motion';

export default function LandingPage() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [showContactPopup, setShowContactPopup] = useState(false);
  const [formData, setFormData] = useState({
    fullName: '',
    clinicName: '',
    clinicAddress: '',
    websiteUrl: '',
    phoneNumber: '',
    email: '',
    preferredLanguages: '',
    appointmentSoftware: '',
    aiHandling: [] as string[],
    otherHandling: ''
  });

  const demos = [
    {
      title: "Booking Whitening",
      description: "Watch how VELTA schedules a teeth whitening appointment naturally",
      duration: "1:23",
      gradient: "from-blue-500 to-purple-600"
    },
    {
      title: "Rescheduling Appointment", 
      description: "See how VELTA handles appointment changes professionally",
      duration: "0:58",
      gradient: "from-purple-500 to-pink-600"
    },
    {
      title: "Answering Questions",
      description: "Experience VELTA answering insurance and service questions",
      duration: "1:45",
      gradient: "from-pink-500 to-red-600"
    }
  ];

  const features = [
    { icon: Zap, title: "24/7 AI Power", description: "Never miss a call again", gradient: "from-yellow-400 to-orange-500" },
    { icon: Cpu, title: "Neural Response", description: "Sub-second call pickup", gradient: "from-blue-400 to-cyan-500" },
    { icon: Brain, title: "Smart Learning", description: "Patients love talking to VELTA", gradient: "from-purple-400 to-pink-500" },
    { icon: Sparkles, title: "Perfect Accuracy", description: "Flawless appointment booking", gradient: "from-green-400 to-emerald-500" }
  ];

  const menuItems = [
    { name: "Demo", href: "#demo-section", icon: Play },
    { name: "Features", href: "#features", icon: Sparkles },
    { name: "Contact", href: "#", icon: Brain, isContact: true },
    { name: "Get Started", href: "#contact", icon: Zap }
  ];

  const handleInputChange = useCallback((field: string, value: string) => {
    setFormData(prev => ({ ...prev, [field]: value }));
  }, []);

  const handleCheckboxChange = useCallback((service: string, checked: boolean) => {
    setFormData(prev => ({
      ...prev,
      aiHandling: checked 
        ? [...prev.aiHandling, service]
        : prev.aiHandling.filter(item => item !== service)
    }));
  }, []);

  const [isSubmitting, setIsSubmitting] = useState(false);
  const [submitMessage, setSubmitMessage] = useState('');

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setIsSubmitting(true);
    
    try {
      // Create well-formatted email data
      const emailData = {
        to: 'info@dorfs-esolutions.com',
        subject: `🦷 VELTA AI Lead: ${formData.clinicName} - ${formData.fullName}`,
        html: `
          <div style="font-family: Arial, sans-serif; max-width: 600px; margin: 0 auto; background: #f8f9fa; padding: 20px;">
            <div style="background: white; padding: 30px; border-radius: 10px; box-shadow: 0 2px 10px rgba(0,0,0,0.1);">
              <h2 style="color: #2563eb; border-bottom: 3px solid #2563eb; padding-bottom: 10px; margin-bottom: 25px;">
                🦷 NEW VELTA AI INQUIRY
              </h2>
              
              <div style="margin-bottom: 25px;">
                <h3 style="color: #1f2937; margin-bottom: 15px; border-left: 4px solid #10b981; padding-left: 10px;">PRACTICE INFORMATION</h3>
                <table style="width: 100%; border-collapse: collapse;">
                  <tr><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;"><strong>👤 Doctor Name:</strong></td><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;">${formData.fullName}</td></tr>
                  <tr><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;"><strong>🏥 Clinic Name:</strong></td><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;">${formData.clinicName}</td></tr>
                  <tr><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;"><strong>📞 Phone:</strong></td><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;">${formData.phoneNumber}</td></tr>
                  <tr><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;"><strong>📧 Email:</strong></td><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;">${formData.email}</td></tr>
                  <tr><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;"><strong>📍 Address:</strong></td><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;">${formData.clinicAddress || 'Not provided'}</td></tr>
                  <tr><td style="padding: 8px 0;"><strong>🌐 Website:</strong></td><td style="padding: 8px 0;">${formData.websiteUrl || 'Not provided'}</td></tr>
                </table>
              </div>

              <div style="margin-bottom: 25px;">
                <h3 style="color: #1f2937; margin-bottom: 15px; border-left: 4px solid #8b5cf6; padding-left: 10px;">TECHNICAL DETAILS</h3>
                <table style="width: 100%; border-collapse: collapse;">
                  <tr><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;"><strong>💬 Languages:</strong></td><td style="padding: 8px 0; border-bottom: 1px solid #e5e7eb;">${formData.preferredLanguages || 'Not specified'}</td></tr>
                  <tr><td style="padding: 8px 0;"><strong>💻 Current Software:</strong></td><td style="padding: 8px 0;">${formData.appointmentSoftware || 'Not specified'}</td></tr>
                </table>
              </div>

              <div style="margin-bottom: 25px;">
                <h3 style="color: #1f2937; margin-bottom: 15px; border-left: 4px solid #f59e0b; padding-left: 10px;">AI SERVICES REQUESTED</h3>
                ${formData.aiHandling.length > 0 ? 
                  `<ul style="margin: 0; padding-left: 20px; color: #374151;">
                    ${formData.aiHandling.map(service => `<li style="margin-bottom: 5px;">✓ ${service}</li>`).join('')}
                  </ul>` : 
                  '<p style="color: #6b7280; font-style: italic;">No specific services selected</p>'
                }
              </div>

              <div style="margin-bottom: 25px;">
                <h3 style="color: #1f2937; margin-bottom: 15px; border-left: 4px solid #ef4444; padding-left: 10px;">SPECIAL NOTES</h3>
                <p style="background: #f3f4f6; padding: 15px; border-radius: 8px; margin: 0; color: #374151;">
                  ${formData.otherHandling || 'None provided'}
                </p>
              </div>

              <div style="background: #dbeafe; padding: 20px; border-radius: 8px; border-left: 4px solid #2563eb;">
                <p style="margin: 0; color: #1e40af; font-weight: 600;">
                  🚀 Ready to contact and set up demo call!
                </p>
              </div>
            </div>
          </div>
        `
      };

      // Send email via API
      const response = await fetch('/api/send-email', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(emailData),
      });

      if (response.ok) {
        setSubmitMessage('✓ Inquiry sent successfully! Our sales team will contact you shortly.');
        // Reset form
        setFormData({
          fullName: '',
          clinicName: '',
          clinicAddress: '',
          websiteUrl: '',
          phoneNumber: '',
          email: '',
          preferredLanguages: '',
          appointmentSoftware: '',
          aiHandling: [] as string[],
          otherHandling: ''
        });
      } else {
        throw new Error('Failed to send email');
      }
    } catch (error) {
      setSubmitMessage('⚠ Failed to send inquiry. Please try again or contact us directly.');
    } finally {
      setIsSubmitting(false);
    }
  };

  const handleMenuClick = (item: any) => {
    if (item.isContact) {
      setShowContactPopup(true);
    } else {
      const element = document.querySelector(item.href);
      if (element) {
        element.scrollIntoView({ behavior: 'smooth' });
      }
    }
    setIsMenuOpen(false);
  };

  return (
    <div className="min-h-screen bg-black text-white relative overflow-hidden">
      {/* Animated Background */}
      <div className="absolute inset-0 bg-gradient-to-br from-blue-900/20 via-purple-900/20 to-pink-900/20" />
      <div className="absolute inset-0">
        <div className="absolute top-1/4 left-1/4 w-96 h-96 bg-blue-500/10 rounded-full blur-3xl animate-pulse" />
        <div className="absolute bottom-1/4 right-1/4 w-96 h-96 bg-purple-500/10 rounded-full blur-3xl animate-pulse delay-1000" />
        <div className="absolute top-1/2 left-1/2 w-96 h-96 bg-pink-500/10 rounded-full blur-3xl animate-pulse delay-2000" />
      </div>

      {/* Futuristic Navigation */}
      <motion.nav 
        className="relative z-50 flex items-center justify-between p-6 bg-black/20 backdrop-blur-xl border-b border-white/10"
        initial={{ y: -100 }}
        animate={{ y: 0 }}
        transition={{ duration: 0.8 }}
      >
        <motion.div 
          className="text-3xl font-bold bg-gradient-to-r from-blue-400 via-purple-400 to-pink-400 bg-clip-text text-transparent"
          whileHover={{ scale: 1.05 }}
        >
          VELTA AI
        </motion.div>

        {/* Desktop Menu */}
        <div className="hidden md:flex items-center space-x-8">
          {menuItems.map((item, index) => (
            <motion.button
              key={item.name}
              onClick={() => handleMenuClick(item)}
              className="flex items-center space-x-2 px-4 py-2 rounded-full bg-white/5 hover:bg-white/10 border border-white/10 hover:border-white/20 transition-all group"
              whileHover={{ scale: 1.05, y: -2 }}
              initial={{ opacity: 0, x: 20 }}
              animate={{ opacity: 1, x: 0 }}
              transition={{ delay: index * 0.1 }}
            >
              <item.icon className="w-4 h-4 text-blue-400 group-hover:text-white transition-colors" />
              <span className="text-sm font-medium">{item.name}</span>
            </motion.button>
          ))}
        </div>

        {/* Mobile Menu Button */}
        <Button
          variant="ghost"
          size="sm"
          className="md:hidden text-white hover:bg-white/10"
          onClick={() => setIsMenuOpen(!isMenuOpen)}
        >
          {isMenuOpen ? <X className="w-6 h-6" /> : <Menu className="w-6 h-6" />}
        </Button>
      </motion.nav>

      {/* Mobile Menu */}
      <AnimatePresence>
        {isMenuOpen && (
          <motion.div
            className="fixed inset-0 z-40 bg-black/95 backdrop-blur-xl md:hidden"
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            exit={{ opacity: 0 }}
          >
            <div className="flex flex-col items-center justify-center h-full space-y-8">
              {menuItems.map((item, index) => (
                <motion.button
                  key={item.name}
                  onClick={() => handleMenuClick(item)}
                  className="flex items-center space-x-4 text-2xl font-medium text-white hover:text-blue-400 transition-colors"
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  transition={{ delay: index * 0.1 }}
                >
                  <item.icon className="w-8 h-8" />
                  <span>{item.name}</span>
                </motion.button>
              ))}
            </div>
          </motion.div>
        )}
      </AnimatePresence>

      {/* Hero Section */}
      <section className="relative z-10 px-6 py-20">
        <div className="mx-auto max-w-6xl text-center">
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.8 }}
          >
            <Badge className="mb-6 bg-gradient-to-r from-blue-500/20 to-purple-500/20 text-blue-300 border-blue-500/30">
              🚀 Revolutionizing Dental Communication with AI
            </Badge>
            
            <motion.h1 
              className="mb-6 text-6xl md:text-8xl font-bold bg-gradient-to-r from-blue-400 via-purple-400 to-pink-400 bg-clip-text text-transparent"
              initial={{ scale: 0.8 }}
              animate={{ scale: 1 }}
              transition={{ duration: 1, delay: 0.2 }}
            >
              VELTA AI
            </motion.h1>
            
            <h2 className="mb-8 text-xl md:text-4xl font-semibold text-gray-300">
              Your 24/7 AI Voice Receptionist for Dental Clinics
            </h2>
            
            <p className="mb-10 text-lg md:text-xl text-gray-400 max-w-3xl mx-auto leading-relaxed">
              Never miss a patient call again. Our AI agent answers, schedules, and supports your patients 
              just like a real receptionist – but faster, smarter, and always on.
            </p>
            
            <Button 
              size="lg" 
              className="bg-gradient-to-r from-blue-600 to-purple-600 hover:from-blue-700 hover:to-purple-700 text-white px-8 py-6 text-lg rounded-full border border-blue-500/30 hover:border-blue-400/50 transition-all shadow-lg shadow-blue-500/25"
              onClick={() => document.getElementById('demo-section')?.scrollIntoView({ behavior: 'smooth' })}
            >
              → Experience the Future ↓
            </Button>
          </motion.div>
        </div>

        {/* Features Grid */}
        <motion.div 
          className="mx-auto max-w-6xl mt-20 grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6"
          initial={{ opacity: 0, y: 40 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.8, delay: 0.4 }}
        >
          {features.map((feature, index) => (
            <motion.div
              key={index}
              className="group relative"
              whileHover={{ y: -10 }}
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ delay: index * 0.1 }}
            >
              <Card className="border-none bg-white/5 backdrop-blur-sm hover:bg-white/10 transition-all border border-white/10 hover:border-white/20 h-48 flex flex-col">
                <CardContent className="p-8 text-center flex flex-col justify-center h-full">
                  <div className={`w-16 h-16 mx-auto mb-6 rounded-full bg-gradient-to-r ${feature.gradient} flex items-center justify-center`}>
                    <feature.icon className="w-8 h-8 text-white" />
                  </div>
                  <h3 className="font-semibold mb-3 text-white text-lg">{feature.title}</h3>
                  <p className="text-sm text-gray-400 flex-1">{feature.description}</p>
                </CardContent>
              </Card>
            </motion.div>
          ))}
        </motion.div>
      </section>

      {/* Compact Features Section */}
      <section id="features" className="py-16 px-6 relative z-10">
        <div className="mx-auto max-w-5xl">
          <motion.div 
            className="text-center mb-12"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <h2 className="text-2xl md:text-5xl font-bold mb-4 bg-gradient-to-r from-green-400 to-blue-400 bg-clip-text text-transparent">
              ⚡ Why Choose VELTA AI
            </h2>
            <p className="text-base md:text-lg text-gray-400 max-w-2xl mx-auto">
              Transform your practice with AI that increases revenue while reducing costs.
            </p>
          </motion.div>

          {/* Compact 2x2 Grid */}
          <div className="grid grid-cols-1 md:grid-cols-2 gap-6 mb-12">
            {[
              {
                icon: TrendingUp,
                title: "Capture More Appointments",
                description: "Never miss after-hours calls. VELTA books patients when your office is closed.",
                gradient: "from-green-400 to-emerald-500",
                stats: "24/7 Availability • No Missed Calls"
              },
              {
                icon: Clock,
                title: "Reduce Staff Phone Time",
                description: "Free your team from repetitive scheduling calls and common questions.",
                gradient: "from-blue-400 to-cyan-500",
                stats: "Automated Responses • Staff Efficiency"
              },
              {
                icon: Brain,
                title: "Seamless Integration",
                description: "Works with Dentrix, OpenDental, or any practice management software.",
                gradient: "from-indigo-400 to-purple-500",
                stats: "Any Software • Easy Setup"
              },
              {
                icon: Shield,
                title: "Professional Every Time",
                description: "Consistent, friendly service that never has bad days or forgets protocols.",
                gradient: "from-purple-400 to-pink-500",
                stats: "Perfect Consistency • Professional Voice"
              }
            ].map((feature, index) => (
              <motion.div
                key={index}
                className="group relative"
                initial={{ opacity: 0, y: 30 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: index * 0.1 }}
                viewport={{ once: true }}
                whileHover={{ y: -5 }}
              >
                <Card className="border-none bg-white/5 backdrop-blur-sm hover:bg-white/10 transition-all border border-white/10 hover:border-white/20 h-56 md:h-48 flex flex-col overflow-hidden">
                  <CardContent className="p-4 pb-6 md:p-5 flex flex-col h-full">
                    <div className="flex items-start space-x-4 flex-1">
                      <div className={`w-16 h-16 rounded-xl bg-gradient-to-r ${feature.gradient} flex items-center justify-center flex-shrink-0`}>
                        <feature.icon className="w-8 h-8 text-white" />
                      </div>
                      <div className="flex-1 flex flex-col h-full min-h-0">
                        <div>
                          <h3 className="text-lg font-bold mb-3 text-white">{feature.title}</h3>
                          <p className="text-sm text-gray-400 mb-2 leading-relaxed">{feature.description}</p>
                          <div className="text-xs text-green-400 font-medium">
                            {feature.stats}
                          </div>
                        </div>
                      </div>
                    </div>
                  </CardContent>
                </Card>
              </motion.div>
            ))}
          </div>


        </div>
      </section>

      {/* TikTok-Style Demo Videos */}
      <section id="demo-section" className="py-20 px-6 relative z-10">
        <div className="mx-auto max-w-6xl">
          <motion.div 
            className="text-center mb-12"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <h2 className="text-2xl md:text-6xl font-bold mb-4 bg-gradient-to-r from-blue-400 to-purple-400 bg-clip-text text-transparent">
              🌟 Watch VELTA AI In Action
            </h2>
            <p className="text-base md:text-xl text-gray-400 max-w-3xl mx-auto">
              Experience real calls made by our AI agent – from booking teeth whitening appointments 
              to handling insurance questions. Your patients won't even know it's AI.
            </p>
          </motion.div>

          {/* TikTok-Style Vertical Videos Row */}
          <div className="grid grid-cols-1 md:grid-cols-3 gap-8 max-w-5xl mx-auto">
            {demos.map((demo, index) => (
              <motion.div
                key={index}
                className="group relative"
                initial={{ opacity: 0, y: 40 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.6, delay: index * 0.2 }}
                viewport={{ once: true }}
                whileHover={{ y: -10 }}
              >
                <Card className="overflow-hidden bg-gray-900/50 backdrop-blur-sm border border-white/10 hover:border-white/20 transition-all flex flex-col h-[580px]">
                  <CardContent className="p-0 flex flex-col h-full">
                    {/* Vertical Video Container - TikTok Style */}
                    <div className="relative h-[400px] bg-gradient-to-br from-gray-800 to-gray-900 flex items-center justify-center">
                      <div className={`absolute inset-0 bg-gradient-to-br ${demo.gradient} opacity-20`} />
                      <div className="relative z-10 text-center text-white px-8 py-8 flex flex-col h-full">
                        <div className="flex-1 flex flex-col justify-center">
                          <div className="w-16 h-16 mx-auto mb-4 rounded-full bg-white/20 backdrop-blur-sm flex items-center justify-center">
                            <Play className="w-8 h-8 text-white" />
                          </div>
                          <div className="mb-4">
                            <Badge variant="secondary" className="bg-green-500/20 text-green-400 border-green-400/30 text-sm px-3 py-1">
                              {demo.duration}
                            </Badge>
                          </div>
                          <h3 className="text-lg font-semibold">{demo.title}</h3>
                        </div>
                      </div>
                    </div>
                    
                    {/* Video Info */}
                    <div className="p-6 flex-1 flex flex-col justify-center">
                      <h4 className="font-semibold text-white mb-3">{demo.title}</h4>
                      <p className="text-sm text-gray-400 leading-relaxed">{demo.description}</p>
                    </div>
                  </CardContent>
                </Card>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* Contact Form */}
      <section id="contact" className="py-20 px-6 relative z-10">
        <div className="mx-auto max-w-4xl">
          <motion.div 
            className="text-center mb-12"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <h2 className="text-2xl md:text-6xl font-bold mb-4 bg-gradient-to-r from-purple-400 to-pink-400 bg-clip-text text-transparent leading-tight md:leading-tight">
              📬 Configure VELTA AI
            </h2>
            <p className="text-base md:text-xl text-gray-400 max-w-3xl mx-auto">
              Fill out a few details about your practice so we can customize your AI assistant before the call.
            </p>
          </motion.div>

          <Card className="bg-black/40 backdrop-blur-xl shadow-2xl border border-white/10">
            <CardContent className="p-8">
              <form onSubmit={handleSubmit} className="space-y-6">
                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                  <div>
                    <label className="block text-sm font-medium mb-2 text-gray-300">Full Name *</label>
                    <Input 
                      required
                      value={formData.fullName}
                      onChange={(e) => handleInputChange('fullName', e.target.value)}
                      placeholder="Dr. John Smith"
                      className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium mb-2 text-gray-300">Clinic Name *</label>
                    <Input 
                      required
                      value={formData.clinicName}
                      onChange={(e) => handleInputChange('clinicName', e.target.value)}
                      placeholder="Smith Family Dentistry"
                      className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium mb-2 text-gray-300">Phone Number *</label>
                    <Input 
                      required
                      type="tel"
                      value={formData.phoneNumber}
                      onChange={(e) => handleInputChange('phoneNumber', e.target.value)}
                      placeholder="(555) 123-4567"
                      className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium mb-2 text-gray-300">Email *</label>
                    <Input 
                      required
                      type="email"
                      value={formData.email}
                      onChange={(e) => handleInputChange('email', e.target.value)}
                      placeholder="dr.smith@example.com"
                      className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                    />
                  </div>
                </div>

                <div>
                  <label className="block text-sm font-medium mb-2 text-gray-300">Clinic Address</label>
                  <Input 
                    value={formData.clinicAddress}
                    onChange={(e) => handleInputChange('clinicAddress', e.target.value)}
                    placeholder="123 Main St, City, State 12345"
                    className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                  />
                </div>

                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                  <div>
                    <label className="block text-sm font-medium mb-2 text-gray-300">Website URL</label>
                    <Input 
                      value={formData.websiteUrl}
                      onChange={(e) => handleInputChange('websiteUrl', e.target.value)}
                      placeholder="https://yourpractice.com"
                      className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium mb-2 text-gray-300">Preferred Languages</label>
                    <Input 
                      value={formData.preferredLanguages}
                      onChange={(e) => handleInputChange('preferredLanguages', e.target.value)}
                      placeholder="English, Spanish"
                      className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                    />
                  </div>
                </div>

                <div>
                  <label className="block text-sm font-medium mb-2 text-gray-300">Appointment Software Used</label>
                  <Input 
                    value={formData.appointmentSoftware}
                    onChange={(e) => handleInputChange('appointmentSoftware', e.target.value)}
                    placeholder="Dentrix, OpenDental, etc."
                    className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                  />
                </div>

                <div>
                  <label className="block text-sm font-medium mb-4 text-gray-300">What do you want your AI agent to handle?</label>
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                    {[
                      'New patient bookings',
                      'Rescheduling',
                      'Insurance questions', 
                      'Hours & service info',
                      'Emergency call handling'
                    ].map((service) => (
                      <div key={service} className="flex items-center space-x-3">
                        <Checkbox 
                          id={service}
                          checked={formData.aiHandling.includes(service)}
                          onCheckedChange={(checked) => handleCheckboxChange(service, checked as boolean)}
                          className="border-white/30 data-[state=checked]:bg-blue-600"
                        />
                        <label htmlFor={service} className="text-sm text-gray-300">{service}</label>
                      </div>
                    ))}
                  </div>
                </div>

                <div>
                  <label className="block text-sm font-medium mb-2 text-gray-300">Other (please specify)</label>
                  <Textarea 
                    value={formData.otherHandling}
                    onChange={(e) => handleInputChange('otherHandling', e.target.value)}
                    placeholder="Any other specific requirements..."
                    rows={3}
                    className="bg-white/5 border-white/20 text-white placeholder-gray-500 focus:border-blue-400"
                  />
                </div>

                <div className="space-y-3">
                  <Button 
                    type="submit"
                    disabled={isSubmitting}
                    className="w-full bg-gradient-to-r from-blue-600 to-purple-600 hover:from-blue-700 hover:to-purple-700 text-white py-6 text-xs md:text-lg rounded-full border border-blue-500/30 hover:border-blue-400/50 transition-all shadow-lg shadow-blue-500/25 disabled:opacity-50"
                    size="lg"
                  >
                    {isSubmitting ? 'Sending...' : (
                      <>
                        <span className="block md:hidden">Send Inquiry</span>
                        <span className="hidden md:block">Send Inquiry for VELTA AI Integration</span>
                      </>
                    )}
                  </Button>
                  
                  <p className="text-sm text-gray-400 text-center">
                    * Sales team will get back to you shortly after reviewing your inquiry. Thank you
                  </p>
                  
                  {submitMessage && (
                    <div className={`text-center p-3 rounded-lg ${submitMessage.includes('✓') ? 'bg-green-500/10 text-green-400' : 'bg-red-500/10 text-red-400'}`}>
                      {submitMessage}
                    </div>
                  )}
                </div>
              </form>
            </CardContent>
          </Card>
        </div>
      </section>

      {/* Futuristic Footer */}
      <footer className="bg-black/60 backdrop-blur-xl border-t border-white/10 text-white py-12 px-6 relative z-10">
        <div className="mx-auto max-w-6xl">
          <div className="grid grid-cols-1 md:grid-cols-4 gap-8">
            <div>
              <h3 className="text-3xl font-bold mb-4 bg-gradient-to-r from-blue-400 to-purple-400 bg-clip-text text-transparent">
                VELTA AI
              </h3>
              <p className="text-gray-400">
                Revolutionizing dental communication with AI-powered voice assistants.
              </p>
            </div>
            
            <div>
              <h4 className="font-semibold mb-4 text-white">Navigation</h4>
              <ul className="space-y-2 text-gray-400">
                <li><a href="#demo-section" className="hover:text-blue-400 transition-colors">Demo</a></li>
                <li><a href="#features" className="hover:text-blue-400 transition-colors">Features</a></li>
                <li><a href="#contact" className="hover:text-blue-400 transition-colors">Get Started</a></li>
                <li><button onClick={() => setShowContactPopup(true)} className="hover:text-blue-400 transition-colors text-left">Contact</button></li>
              </ul>
            </div>
            
            <div>
              <h4 className="font-semibold mb-4 text-white">Legal</h4>
              <ul className="space-y-2 text-gray-400">
                <li><a href="/terms" className="hover:text-blue-400 transition-colors">Terms of Service</a></li>
                <li><a href="/privacy" className="hover:text-blue-400 transition-colors">Privacy Policy</a></li>
              </ul>
            </div>
            
            <div>
              <h4 className="font-semibold mb-4 text-white">Contact</h4>
              <a 
                href="mailto:info@dorfs-esolutions.com" 
                className="text-gray-400 hover:text-blue-400 transition-colors block mb-4"
              >
                info@dorfs-esolutions.com
              </a>
              <a 
                href="tel:+38641995091" 
                className="text-gray-400 hover:text-blue-400 transition-colors block"
              >
                +386 41 995 091
              </a>
            </div>
          </div>
          
          <div className="border-t border-white/10 mt-8 pt-8 text-center text-gray-400">
            <p>© 2025 VELTA AI – All rights reserved.</p>
          </div>
        </div>
      </footer>

      {/* Contact Popup */}
      <AnimatePresence>
        {showContactPopup && (
          <motion.div
            className="fixed inset-0 z-50 bg-black/80 backdrop-blur-sm flex items-center justify-center p-4"
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            exit={{ opacity: 0 }}
            onClick={() => setShowContactPopup(false)}
          >
            <motion.div
              className="bg-gray-900/95 backdrop-blur-xl border border-white/20 rounded-2xl p-8 max-w-md w-full"
              initial={{ scale: 0.8, opacity: 0 }}
              animate={{ scale: 1, opacity: 1 }}
              exit={{ scale: 0.8, opacity: 0 }}
              onClick={(e) => e.stopPropagation()}
            >
              <div className="flex justify-between items-center mb-6">
                <h3 className="text-2xl font-bold bg-gradient-to-r from-blue-400 to-purple-400 bg-clip-text text-transparent">
                  Contact Us
                </h3>
                <Button
                  variant="ghost"
                  size="sm"
                  onClick={() => setShowContactPopup(false)}
                  className="text-gray-400 hover:text-white"
                >
                  <X className="w-5 h-5" />
                </Button>
              </div>

              <div className="space-y-6">
                <div className="text-center">
                  <p className="text-gray-300 mb-6">
                    Ready to transform your dental practice? Get in touch with our team.
                  </p>
                </div>

                <div className="space-y-4">
                  <a
                    href="mailto:info@dorfs-esolutions.com"
                    className="flex items-center space-x-4 p-4 rounded-xl bg-white/5 hover:bg-white/10 border border-white/10 hover:border-white/20 transition-all group"
                  >
                    <div className="w-12 h-12 rounded-full bg-gradient-to-r from-blue-500 to-purple-500 flex items-center justify-center">
                      <Mail className="w-6 h-6 text-white" />
                    </div>
                    <div>
                      <div className="font-semibold text-white group-hover:text-blue-400 transition-colors">
                        Email Us
                      </div>
                      <div className="text-sm text-gray-400">
                        info@dorfs-esolutions.com
                      </div>
                    </div>
                  </a>

                  <a
                    href="tel:+38641995091"
                    className="flex items-center space-x-4 p-4 rounded-xl bg-white/5 hover:bg-white/10 border border-white/10 hover:border-white/20 transition-all group"
                  >
                    <div className="w-12 h-12 rounded-full bg-gradient-to-r from-green-500 to-blue-500 flex items-center justify-center">
                      <Phone className="w-6 h-6 text-white" />
                    </div>
                    <div>
                      <div className="font-semibold text-white group-hover:text-green-400 transition-colors">
                        Call Us
                      </div>
                      <div className="text-sm text-gray-400">
                        +386 41 995 091
                      </div>
                    </div>
                  </a>
                </div>

                <div className="text-center pt-4">
                  <p className="text-sm text-gray-500">
                    Available Monday-Friday, 9 AM - 6 PM CET
                  </p>
                </div>
              </div>
            </motion.div>
          </motion.div>
        )}
      </AnimatePresence>
    </div>
  );
}